"use strict";
/*
 * Copyright © 2019 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const sdm_1 = require("@atomist/sdm");
const DockerProgressReporter_1 = require("./DockerProgressReporter");
const executeDockerBuild_1 = require("./executeDockerBuild");
const DefaultDockerOptions = {
    dockerImageNameCreator: executeDockerBuild_1.DefaultDockerImageNameCreator,
    dockerfileFinder: () => __awaiter(this, void 0, void 0, function* () { return "Dockerfile"; }),
    push: false,
    builder: "docker",
    builderArgs: [],
};
/**
 * Goal that performs docker build and push depending on the provided options
 */
class DockerBuild extends sdm_1.FulfillableGoalWithRegistrations {
    constructor(goalDetailsOrUniqueName = sdm_1.DefaultGoalNameGenerator.generateName("docker-build"), ...dependsOn) {
        super(sdm_1.getGoalDefinitionFrom(goalDetailsOrUniqueName, sdm_1.DefaultGoalNameGenerator.generateName("docker-build"), DockerBuildDefinition), ...dependsOn);
        this.goalDetailsOrUniqueName = goalDetailsOrUniqueName;
    }
    with(registration) {
        const optsToUse = sdm_1.mergeOptions(DefaultDockerOptions, registration.options);
        // Backwards compatibility
        // tslint:disable:deprecation
        if (!!registration.imageNameCreator && (!registration.options || !registration.options.dockerImageNameCreator)) {
            optsToUse.dockerImageNameCreator = registration.imageNameCreator;
        }
        // tslint:enable:deprecation
        this.addFulfillment(Object.assign({ goalExecutor: executeDockerBuild_1.executeDockerBuild(optsToUse), name: sdm_1.DefaultGoalNameGenerator.generateName("docker-builder"), progressReporter: DockerProgressReporter_1.DockerProgressReporter }, registration));
        return this;
    }
}
exports.DockerBuild = DockerBuild;
const DockerBuildDefinition = {
    uniqueName: "docker-build",
    displayName: "docker build",
    environment: sdm_1.IndependentOfEnvironment,
    workingDescription: "Running docker build",
    completedDescription: "Docker build successful",
    failedDescription: "Docker build failed",
    isolated: true,
    retryFeasible: true,
};
//# sourceMappingURL=DockerBuild.js.map