import { GitProject, HandlerContext } from "@atomist/automation-client";
import { ExecuteGoal, SdmGoalEvent } from "@atomist/sdm";
/**
 * Options to configure the Docker image build
 */
export interface DockerOptions {
    /**
     * Provide the image tag for the docker image to build
     */
    dockerImageNameCreator?: DockerImageNameCreator;
    /**
     * True if the docker image should be pushed to the registry
     */
    push?: boolean;
    /**
     * Optional registry to push the docker image too.
     * Needs to set when push === true
     */
    registry?: string;
    /**
     * Optional user to use when pushing the docker image.
     * Needs to set when push === true
     */
    user?: string;
    /**
     * Optional password to use when pushing the docker image.
     * Needs to set when push === true
     */
    password?: string;
    /**
     * Optional Docker config in json as alternative to running
     * 'docker login' with provided registry, user and password.
     */
    config?: string;
    /**
     * Find the Dockerfile within the project
     * @param p the project
     */
    dockerfileFinder?: (p: GitProject) => Promise<string>;
    /**
     * Optionally specify what docker image builder to use.
     * Defaults to "docker"
     */
    builder?: "docker" | "kaniko";
    /**
     * Optional arguments passed to the docker image builder
     */
    builderArgs?: string[];
}
export declare type DockerImageNameCreator = (p: GitProject, sdmGoal: SdmGoalEvent, options: DockerOptions, ctx: HandlerContext) => Promise<{
    registry: string;
    name: string;
    tags: string[];
}>;
/**
 * Execute a Docker build for the project
 * @param {DockerImageNameCreator} imageNameCreator
 * @param {DockerOptions} options
 * @returns {ExecuteGoal}
 */
export declare function executeDockerBuild(options: DockerOptions): ExecuteGoal;
export declare const DefaultDockerImageNameCreator: DockerImageNameCreator;
